==> 5.4.72.zip: dde-dock/translations/dde-dock_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Shtojca %1 s’është e përputhshme me sistemin.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Hiqe</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 u lidh</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Po lidhet…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>I çaktivizuar</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Shtoni skemë tastiere</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datë dhe kohë</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Orë 12-orëshe</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Orë 24-orëshe</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Rregullime kohe</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Jeni i sigurt se doni të zbrazen $1 objekte?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Për këtë veprim s’mund të bëhet rikthim</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Pajisje e panjohur</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Vëllim i panjohur</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Çmontoji krejt</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Nisës</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Dil nga Mënyra e Parrezik</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Panel - Mënyra e Parrezik</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Paneli gjendet nën Mënyrën e Parrezik, ju lutemi, dilni prej saj, që të shfaqet si duhet</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mënyra Modë</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mënyra Efikase</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Në Krye</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Në Fund</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mbaje të Shfaqur</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mbaje të Fshehur</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Fshehje e Mençur</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vendndodhje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Shtojca</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Vetëm në ekranin kryesor</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Në ekranin ku është kursori</translation>
    </message>
    <message>
        <source>Show the Dock</source>
        <translation>Shfaqe Panelin</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Pamje Multitasking</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Çaktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Çaktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Lidhje pa fill: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Lidhje me fill: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po bëhet lidhja</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>I lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Lidhja dështoi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Rrjet</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energji</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, edhe %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, edhe %2 hr %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Po ngarkohet %1, edhe %2 min deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Po ngarkohet %1, edhe %2 hr e %3 min deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Po ngarkohet %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1 …</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet 1%, plotësisht e ngarkuar</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Shfaq Desktopin</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energji</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kyçe</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Këmbeni llogari</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Pajisje</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ktheji zërin</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Pa zë</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Rregullime zëri</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volumi %1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zë</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Hedhurina</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Hedhurina - %1 kartelë</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Hedhurina - %1 kartela</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>E zbrazët</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
</TS>

==> 5.5.70.zip: dde-dock/translations/dde-dock_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>Shtojca %1 s’është e përputhshme me sistemin.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Mënyra aeroplan është e aktivizuar</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Rregullime Mënyre Aeroplan</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Mënyra aeroplan është e çaktivizuar</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Mënyra Aeroplan</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Hiqe</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Çaktivizoje</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Aktivizoje</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Rregullime Bluetooth-i</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 u lidh</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Po lidhet…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>I çaktivizuar</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Shtoni skemë tastiere</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datë dhe kohë</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>Orë 12-orëshe</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>Orë 24-orëshe</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Rregullime kohe</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>E hënë</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>E martë</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>E mërkurë</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>E enjte</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>E premte</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>E shtunë</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>E diel</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>e hënë</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>e martë</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>e mërkurë</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>e enjte</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>e premte</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>e shtunë</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>e diel</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Jeni i sigurt se doni të zbrazen $1 objekte?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Për këtë veprim s’mund të bëhet rikthim</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Pajisje e panjohur</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Vëllim i panjohur</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Çmontoji krejt</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Nisës</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Dil nga Mënyra e Parrezik</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Panel - Mënyra e Parrezik</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Paneli gjendet nën Mënyrën e Parrezik, ju lutemi, dilni prej saj, që të shfaqet si duhet</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Mënyra Modë</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Mënyra Efikase</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Në Krye</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Në Fund</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Mbaje të Shfaqur</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Mbaje të Fshehur</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Fshehje e Mençur</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vendndodhje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Rregullime paneli</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Madhësi</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Shumë Ekrane</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Zonë Shtojcash</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Përzgjidhni cilat ikona shfaqen te Paneli</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Mënyra modë</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Mënyra efikasitet</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Në Krye</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Në Fund</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Majtas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Djathtas</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vendndodhje</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Mbaje të shfaqur</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Mbaje të fshehur</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Fshehje e mençur</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>I vogël</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>I madh</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Shfaqe Panelin</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Në ekranin ku është kursori</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Vetëm në ekranin kryesor</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Pamje Multitasking</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energji</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Kapacitet %1, edhe %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Kapacitet %1, edhe %2 hr %3 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Po ngarkohet %1, edhe %2 min deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Po ngarkohet %1, edhe %2 hr e %3 min deri sa të jetë plot</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Kapacitet %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Po ngarkohet %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Kapacitet %1 …</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Kapacitet 1%, plotësisht e ngarkuar</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Panel</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mënyrë</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Vendndodhje</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Gjendje</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Madhësi</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Shfaqe Panelin</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Zonë Shtojcash</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Shfaq Desktopin</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Hiqe nga paneli</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energji</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Fike</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pezulloje</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Plogështoje</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kyçe</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Dilni</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Këmbeni llogari</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Rregullime energjie</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Rinisu</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ktheji zërin</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Pa zë</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Rregullime zëri</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Volumi %1</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Zë</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Hedhurina</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Hedhurina - %1 kartelë</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Hedhurina - %1 kartela</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Shpjere te Hedhurinat</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>E zbrazët</translation>
    </message>
</context>
</TS>
